# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/trade_data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import trade_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/type/shared/v1/trade_data.proto\x12 systemathics.apis.type.shared.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a,systemathics/apis/type/shared/v1/trade.proto\"\x84\x01\n\tTradeData\x12\x0f\n\x07mapping\x18\x01 \x01(\r\x12.\n\ntime_stamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x05trade\x18\x03 \x01(\x0b\x32\'.systemathics.apis.type.shared.v1.Tradeb\x06proto3')



_TRADEDATA = DESCRIPTOR.message_types_by_name['TradeData']
TradeData = _reflection.GeneratedProtocolMessageType('TradeData', (_message.Message,), {
  'DESCRIPTOR' : _TRADEDATA,
  '__module__' : 'systemathics.apis.type.shared.v1.trade_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.TradeData)
  })
_sym_db.RegisterMessage(TradeData)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRADEDATA._serialized_start=167
  _TRADEDATA._serialized_end=299
# @@protoc_insertion_point(module_scope)
