# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/identifier_and_level.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/type/shared/v1/identifier_and_level.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a,systemathics/apis/type/shared/v1/level.proto\"\x9e\x01\n\x12IdentifierAndLevel\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12.\n\x08provider\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x05level\x18\x04 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Levelb\x06proto3')



_IDENTIFIERANDLEVEL = DESCRIPTOR.message_types_by_name['IdentifierAndLevel']
IdentifierAndLevel = _reflection.GeneratedProtocolMessageType('IdentifierAndLevel', (_message.Message,), {
  'DESCRIPTOR' : _IDENTIFIERANDLEVEL,
  '__module__' : 'systemathics.apis.type.shared.v1.identifier_and_level_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.IdentifierAndLevel)
  })
_sym_db.RegisterMessage(IdentifierAndLevel)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTIFIERANDLEVEL._serialized_start=176
  _IDENTIFIERANDLEVEL._serialized_end=334
# @@protoc_insertion_point(module_scope)
