# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_trades.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import trade_data_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/tick/v1/tick_trades.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a\x31systemathics/apis/type/shared/v1/trade_data.proto\"\xae\x01\n\x11TickTradesRequest\x12\x41\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"\x97\x01\n\x12TickTradesResponse\x12;\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32+.systemathics.apis.type.shared.v1.TradeDataH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\x92\x01\n\x11TickTradesService\x12}\n\nTickTrades\x12\x35.systemathics.apis.services.tick.v1.TickTradesRequest\x1a\x36.systemathics.apis.services.tick.v1.TickTradesResponse0\x01\x62\x06proto3')



_TICKTRADESREQUEST = DESCRIPTOR.message_types_by_name['TickTradesRequest']
_TICKTRADESRESPONSE = DESCRIPTOR.message_types_by_name['TickTradesResponse']
TickTradesRequest = _reflection.GeneratedProtocolMessageType('TickTradesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesRequest)
  })
_sym_db.RegisterMessage(TickTradesRequest)

TickTradesResponse = _reflection.GeneratedProtocolMessageType('TickTradesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesResponse)
  })
_sym_db.RegisterMessage(TickTradesResponse)

_TICKTRADESSERVICE = DESCRIPTOR.services_by_name['TickTradesService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKTRADESREQUEST._serialized_start=325
  _TICKTRADESREQUEST._serialized_end=499
  _TICKTRADESRESPONSE._serialized_start=502
  _TICKTRADESRESPONSE._serialized_end=653
  _TICKTRADESSERVICE._serialized_start=656
  _TICKTRADESSERVICE._serialized_end=802
# @@protoc_insertion_point(module_scope)
