# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_ema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCsystemathics/apis/services/intraday_analytics/v1/intraday_ema.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xfc\x01\n\x12IntradayEmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"f\n\x13IntradayEmaResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday_analytics.v1.IntradayEmaData\"a\n\x0fIntradayEmaData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x01\x32\xb1\x01\n\x12IntradayEmaService\x12\x9a\x01\n\x0bIntradayEma\x12\x44.systemathics.apis.services.intraday_analytics.v1.IntradayEmaRequest\x1a\x45.systemathics.apis.services.intraday_analytics.v1.IntradayEmaResponseb\x06proto3')



_INTRADAYEMAREQUEST = DESCRIPTOR.message_types_by_name['IntradayEmaRequest']
_INTRADAYEMARESPONSE = DESCRIPTOR.message_types_by_name['IntradayEmaResponse']
_INTRADAYEMADATA = DESCRIPTOR.message_types_by_name['IntradayEmaData']
IntradayEmaRequest = _reflection.GeneratedProtocolMessageType('IntradayEmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYEMAREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_ema_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayEmaRequest)
  })
_sym_db.RegisterMessage(IntradayEmaRequest)

IntradayEmaResponse = _reflection.GeneratedProtocolMessageType('IntradayEmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYEMARESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_ema_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayEmaResponse)
  })
_sym_db.RegisterMessage(IntradayEmaResponse)

IntradayEmaData = _reflection.GeneratedProtocolMessageType('IntradayEmaData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYEMADATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_ema_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayEmaData)
  })
_sym_db.RegisterMessage(IntradayEmaData)

_INTRADAYEMASERVICE = DESCRIPTOR.services_by_name['IntradayEmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYEMAREQUEST._serialized_start=339
  _INTRADAYEMAREQUEST._serialized_end=591
  _INTRADAYEMARESPONSE._serialized_start=593
  _INTRADAYEMARESPONSE._serialized_end=695
  _INTRADAYEMADATA._serialized_start=697
  _INTRADAYEMADATA._serialized_end=794
  _INTRADAYEMASERVICE._serialized_start=797
  _INTRADAYEMASERVICE._serialized_end=974
# @@protoc_insertion_point(module_scope)
