# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_sma.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/daily_analytics/v1/daily_sma.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xbb\x01\n\x0f\x44\x61ilySmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"]\n\x10\x44\x61ilySmaResponse\x12I\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailySmaData\"m\n\x0c\x44\x61ilySmaData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12-\n\x07\x61verage\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue2\x9f\x01\n\x0f\x44\x61ilySmaService\x12\x8b\x01\n\x08\x44\x61ilySma\x12>.systemathics.apis.services.daily_analytics.v1.DailySmaRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailySmaResponseb\x06proto3')



_DAILYSMAREQUEST = DESCRIPTOR.message_types_by_name['DailySmaRequest']
_DAILYSMARESPONSE = DESCRIPTOR.message_types_by_name['DailySmaResponse']
_DAILYSMADATA = DESCRIPTOR.message_types_by_name['DailySmaData']
DailySmaRequest = _reflection.GeneratedProtocolMessageType('DailySmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYSMAREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailySmaRequest)
  })
_sym_db.RegisterMessage(DailySmaRequest)

DailySmaResponse = _reflection.GeneratedProtocolMessageType('DailySmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYSMARESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailySmaResponse)
  })
_sym_db.RegisterMessage(DailySmaResponse)

DailySmaData = _reflection.GeneratedProtocolMessageType('DailySmaData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYSMADATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_sma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailySmaData)
  })
_sym_db.RegisterMessage(DailySmaData)

_DAILYSMASERVICE = DESCRIPTOR.services_by_name['DailySmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYSMAREQUEST._serialized_start=272
  _DAILYSMAREQUEST._serialized_end=459
  _DAILYSMARESPONSE._serialized_start=461
  _DAILYSMARESPONSE._serialized_end=554
  _DAILYSMADATA._serialized_start=556
  _DAILYSMADATA._serialized_end=665
  _DAILYSMASERVICE._serialized_start=668
  _DAILYSMASERVICE._serialized_end=827
# @@protoc_insertion_point(module_scope)
