# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v1/tick_trades_and_book.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_and_level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__and__level__pb2
from systemathics.apis.type.shared.v1 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_keys__pb2
from systemathics.apis.type.shared.v1 import book_updates_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_book__updates__pb2
from systemathics.apis.type.shared.v1 import trade_and_book_data_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_trade__and__book__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/tick/v1/tick_trades_and_book.proto\x12\"systemathics.apis.services.tick.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a;systemathics/apis/type/shared/v1/identifier_and_level.proto\x1a+systemathics/apis/type/shared/v1/keys.proto\x1a\x33systemathics/apis/type/shared/v1/book_updates.proto\x1a:systemathics/apis/type/shared/v1/trade_and_book_data.proto\"\xb2\x02\n\x18TickTradesAndBookRequest\x12I\n\x0bidentifiers\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.type.shared.v1.IdentifierAndLevel\x12\x43\n\x0c\x62ook_updates\x18\x02 \x01(\x0e\x32-.systemathics.apis.type.shared.v1.BookUpdates\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\x12.\n\tmax_depth\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xa5\x01\n\x19TickTradesAndBookResponse\x12\x42\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x32.systemathics.apis.type.shared.v1.TradeAndBookDataH\x00\x12\x39\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.KeysH\x00\x42\t\n\x07payload2\xaf\x01\n\x18TickTradesAndBookService\x12\x92\x01\n\x11TickTradesAndBook\x12<.systemathics.apis.services.tick.v1.TickTradesAndBookRequest\x1a=.systemathics.apis.services.tick.v1.TickTradesAndBookResponse0\x01\x62\x06proto3')



_TICKTRADESANDBOOKREQUEST = DESCRIPTOR.message_types_by_name['TickTradesAndBookRequest']
_TICKTRADESANDBOOKRESPONSE = DESCRIPTOR.message_types_by_name['TickTradesAndBookResponse']
TickTradesAndBookRequest = _reflection.GeneratedProtocolMessageType('TickTradesAndBookRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESANDBOOKREQUEST,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesAndBookRequest)
  })
_sym_db.RegisterMessage(TickTradesAndBookRequest)

TickTradesAndBookResponse = _reflection.GeneratedProtocolMessageType('TickTradesAndBookResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKTRADESANDBOOKRESPONSE,
  '__module__' : 'systemathics.apis.services.tick.v1.tick_trades_and_book_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick.v1.TickTradesAndBookResponse)
  })
_sym_db.RegisterMessage(TickTradesAndBookResponse)

_TICKTRADESANDBOOKSERVICE = DESCRIPTOR.services_by_name['TickTradesAndBookService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKTRADESANDBOOKREQUEST._serialized_start=438
  _TICKTRADESANDBOOKREQUEST._serialized_end=744
  _TICKTRADESANDBOOKRESPONSE._serialized_start=747
  _TICKTRADESANDBOOKRESPONSE._serialized_end=912
  _TICKTRADESANDBOOKSERVICE._serialized_start=915
  _TICKTRADESANDBOOKSERVICE._serialized_end=1090
# @@protoc_insertion_point(module_scope)
