# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_cma.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/daily_analytics/v1/daily_cma.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xab\x01\n\x0f\x44\x61ilyCmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x03 \x01(\x08\"]\n\x10\x44\x61ilyCmaResponse\x12I\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailyCmaData\"O\n\x0c\x44\x61ilyCmaData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x01\x32\x9f\x01\n\x0f\x44\x61ilyCmaService\x12\x8b\x01\n\x08\x44\x61ilyCma\x12>.systemathics.apis.services.daily_analytics.v1.DailyCmaRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailyCmaResponseb\x06proto3')



_DAILYCMAREQUEST = DESCRIPTOR.message_types_by_name['DailyCmaRequest']
_DAILYCMARESPONSE = DESCRIPTOR.message_types_by_name['DailyCmaResponse']
_DAILYCMADATA = DESCRIPTOR.message_types_by_name['DailyCmaData']
DailyCmaRequest = _reflection.GeneratedProtocolMessageType('DailyCmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYCMAREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyCmaRequest)
  })
_sym_db.RegisterMessage(DailyCmaRequest)

DailyCmaResponse = _reflection.GeneratedProtocolMessageType('DailyCmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYCMARESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyCmaResponse)
  })
_sym_db.RegisterMessage(DailyCmaResponse)

DailyCmaData = _reflection.GeneratedProtocolMessageType('DailyCmaData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYCMADATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_cma_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyCmaData)
  })
_sym_db.RegisterMessage(DailyCmaData)

_DAILYCMASERVICE = DESCRIPTOR.services_by_name['DailyCmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYCMAREQUEST._serialized_start=272
  _DAILYCMAREQUEST._serialized_end=443
  _DAILYCMARESPONSE._serialized_start=445
  _DAILYCMARESPONSE._serialized_end=538
  _DAILYCMADATA._serialized_start=540
  _DAILYCMADATA._serialized_end=619
  _DAILYCMASERVICE._serialized_start=622
  _DAILYCMASERVICE._serialized_end=781
# @@protoc_insertion_point(module_scope)
