# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/book_updates.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3systemathics/apis/type/shared/v1/book_updates.proto\x12 systemathics.apis.type.shared.v1*\x88\x01\n\x0b\x42ookUpdates\x12\x1c\n\x18\x42OOK_UPDATES_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x42OOK_UPDATES_SNAPSHOTS_ONLY\x10\x01\x12:\n6BOOK_UPDATES_INITIAL_SNAPSHOT_THEN_INCREMENTAL_UPDATES\x10\x02\x62\x06proto3')

_BOOKUPDATES = DESCRIPTOR.enum_types_by_name['BookUpdates']
BookUpdates = enum_type_wrapper.EnumTypeWrapper(_BOOKUPDATES)
BOOK_UPDATES_UNSPECIFIED = 0
BOOK_UPDATES_SNAPSHOTS_ONLY = 1
BOOK_UPDATES_INITIAL_SNAPSHOT_THEN_INCREMENTAL_UPDATES = 2


if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BOOKUPDATES._serialized_start=90
  _BOOKUPDATES._serialized_end=226
# @@protoc_insertion_point(module_scope)
