# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/time_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v1/time_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x1bgoogle/type/timeofday.proto\"d\n\x0cTimeInterval\x12*\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12(\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayb\x06proto3')



_TIMEINTERVAL = DESCRIPTOR.message_types_by_name['TimeInterval']
TimeInterval = _reflection.GeneratedProtocolMessageType('TimeInterval', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINTERVAL,
  '__module__' : 'systemathics.apis.type.shared.v1.time_interval_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.TimeInterval)
  })
_sym_db.RegisterMessage(TimeInterval)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TIMEINTERVAL._serialized_start=119
  _TIMEINTERVAL._serialized_end=219
# @@protoc_insertion_point(module_scope)
