# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick_analytics/v1/tick_vwap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/tick_analytics/v1/tick_vwap.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xa1\x02\n\x0fTickVwapRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12)\n\x06period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12)\n\x06offset\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x12\n\nadjustment\x18\x05 \x01(\x08\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x06 \x03(\t\x12\x0e\n\x06reject\x18\x07 \x03(\t\"~\n\x10TickVwapResponse\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04vwap\x18\x02 \x01(\x01\x12\r\n\x05trade\x18\x03 \x01(\x01\x12\x0e\n\x06volume\x18\x04 \x01(\x03\x12\r\n\x05ticks\x18\x05 \x01(\x05\x32\x9f\x01\n\x0fTickVwapService\x12\x8b\x01\n\x08TickVwap\x12=.systemathics.apis.services.tick_analytics.v1.TickVwapRequest\x1a>.systemathics.apis.services.tick_analytics.v1.TickVwapResponse0\x01\x62\x06proto3')



_TICKVWAPREQUEST = DESCRIPTOR.message_types_by_name['TickVwapRequest']
_TICKVWAPRESPONSE = DESCRIPTOR.message_types_by_name['TickVwapResponse']
TickVwapRequest = _reflection.GeneratedProtocolMessageType('TickVwapRequest', (_message.Message,), {
  'DESCRIPTOR' : _TICKVWAPREQUEST,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickVwapRequest)
  })
_sym_db.RegisterMessage(TickVwapRequest)

TickVwapResponse = _reflection.GeneratedProtocolMessageType('TickVwapResponse', (_message.Message,), {
  'DESCRIPTOR' : _TICKVWAPRESPONSE,
  '__module__' : 'systemathics.apis.services.tick_analytics.v1.tick_vwap_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.tick_analytics.v1.TickVwapResponse)
  })
_sym_db.RegisterMessage(TickVwapResponse)

_TICKVWAPSERVICE = DESCRIPTOR.services_by_name['TickVwapService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TICKVWAPREQUEST._serialized_start=279
  _TICKVWAPREQUEST._serialized_end=568
  _TICKVWAPRESPONSE._serialized_start=570
  _TICKVWAPRESPONSE._serialized_end=696
  _TICKVWAPSERVICE._serialized_start=699
  _TICKVWAPSERVICE._serialized_end=858
# @@protoc_insertion_point(module_scope)
