# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_ema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=systemathics/apis/services/daily_analytics/v1/daily_ema.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xbb\x01\n\x0f\x44\x61ilyEmaRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"]\n\x10\x44\x61ilyEmaResponse\x12I\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailyEmaData\"O\n\x0c\x44\x61ilyEmaData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0f\n\x07\x61verage\x18\x03 \x01(\x01\x32\x9f\x01\n\x0f\x44\x61ilyEmaService\x12\x8b\x01\n\x08\x44\x61ilyEma\x12>.systemathics.apis.services.daily_analytics.v1.DailyEmaRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailyEmaResponseb\x06proto3')



_DAILYEMAREQUEST = DESCRIPTOR.message_types_by_name['DailyEmaRequest']
_DAILYEMARESPONSE = DESCRIPTOR.message_types_by_name['DailyEmaResponse']
_DAILYEMADATA = DESCRIPTOR.message_types_by_name['DailyEmaData']
DailyEmaRequest = _reflection.GeneratedProtocolMessageType('DailyEmaRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYEMAREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_ema_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyEmaRequest)
  })
_sym_db.RegisterMessage(DailyEmaRequest)

DailyEmaResponse = _reflection.GeneratedProtocolMessageType('DailyEmaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYEMARESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_ema_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyEmaResponse)
  })
_sym_db.RegisterMessage(DailyEmaResponse)

DailyEmaData = _reflection.GeneratedProtocolMessageType('DailyEmaData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYEMADATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_ema_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyEmaData)
  })
_sym_db.RegisterMessage(DailyEmaData)

_DAILYEMASERVICE = DESCRIPTOR.services_by_name['DailyEmaService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYEMAREQUEST._serialized_start=272
  _DAILYEMAREQUEST._serialized_end=459
  _DAILYEMARESPONSE._serialized_start=461
  _DAILYEMARESPONSE._serialized_end=554
  _DAILYEMADATA._serialized_start=556
  _DAILYEMADATA._serialized_end=635
  _DAILYEMASERVICE._serialized_start=638
  _DAILYEMASERVICE._serialized_end=797
# @@protoc_insertion_point(module_scope)
