# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v1/intraday_bars.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:systemathics/apis/services/intraday/v1/intraday_bars.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xed\x01\n\x13IntradayBarsRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"Y\n\x14IntradayBarsResponse\x12\x41\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.intraday.v1.IntradayBar\"\xb1\x01\n\x0bIntradayBar\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04open\x18\x02 \x01(\x01\x12\x0c\n\x04high\x18\x03 \x01(\x01\x12\x0b\n\x03low\x18\x04 \x01(\x01\x12\r\n\x05\x63lose\x18\x05 \x01(\x01\x12\x0e\n\x06volume\x18\x06 \x01(\x03\x12\r\n\x05\x63ount\x18\x07 \x01(\x05\x12\x0c\n\x04vwap\x18\x08 \x01(\x01\x12\r\n\x05score\x18\t \x01(\x01\x32\xa1\x01\n\x13IntradayBarsService\x12\x89\x01\n\x0cIntradayBars\x12;.systemathics.apis.services.intraday.v1.IntradayBarsRequest\x1a<.systemathics.apis.services.intraday.v1.IntradayBarsResponseb\x06proto3')



_INTRADAYBARSREQUEST = DESCRIPTOR.message_types_by_name['IntradayBarsRequest']
_INTRADAYBARSRESPONSE = DESCRIPTOR.message_types_by_name['IntradayBarsResponse']
_INTRADAYBAR = DESCRIPTOR.message_types_by_name['IntradayBar']
IntradayBarsRequest = _reflection.GeneratedProtocolMessageType('IntradayBarsRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBARSREQUEST,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayBarsRequest)
  })
_sym_db.RegisterMessage(IntradayBarsRequest)

IntradayBarsResponse = _reflection.GeneratedProtocolMessageType('IntradayBarsResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBARSRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayBarsResponse)
  })
_sym_db.RegisterMessage(IntradayBarsResponse)

IntradayBar = _reflection.GeneratedProtocolMessageType('IntradayBar', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBAR,
  '__module__' : 'systemathics.apis.services.intraday.v1.intraday_bars_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday.v1.IntradayBar)
  })
_sym_db.RegisterMessage(IntradayBar)

_INTRADAYBARSSERVICE = DESCRIPTOR.services_by_name['IntradayBarsService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYBARSREQUEST._serialized_start=288
  _INTRADAYBARSREQUEST._serialized_end=525
  _INTRADAYBARSRESPONSE._serialized_start=527
  _INTRADAYBARSRESPONSE._serialized_end=616
  _INTRADAYBAR._serialized_start=619
  _INTRADAYBAR._serialized_end=796
  _INTRADAYBARSSERVICE._serialized_start=799
  _INTRADAYBARSSERVICE._serialized_end=960
# @@protoc_insertion_point(module_scope)
