# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_macd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/daily_analytics/v1/daily_macd.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xc9\x01\n\x10\x44\x61ilyMacdRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0c\n\x04long\x18\x03 \x01(\x05\x12\r\n\x05short\x18\x04 \x01(\x05\x12\x12\n\nadjustment\x18\x05 \x01(\x08\"_\n\x11\x44\x61ilyMacdResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.daily_analytics.v1.DailyMacdData\"j\n\rDailyMacdData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0c\n\x04macd\x18\x03 \x01(\x01\x12\r\n\x05short\x18\x04 \x01(\x01\x12\x0c\n\x04long\x18\x05 \x01(\x01\x32\xa3\x01\n\x10\x44\x61ilyMacdService\x12\x8e\x01\n\tDailyMacd\x12?.systemathics.apis.services.daily_analytics.v1.DailyMacdRequest\x1a@.systemathics.apis.services.daily_analytics.v1.DailyMacdResponseb\x06proto3')



_DAILYMACDREQUEST = DESCRIPTOR.message_types_by_name['DailyMacdRequest']
_DAILYMACDRESPONSE = DESCRIPTOR.message_types_by_name['DailyMacdResponse']
_DAILYMACDDATA = DESCRIPTOR.message_types_by_name['DailyMacdData']
DailyMacdRequest = _reflection.GeneratedProtocolMessageType('DailyMacdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMACDREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyMacdRequest)
  })
_sym_db.RegisterMessage(DailyMacdRequest)

DailyMacdResponse = _reflection.GeneratedProtocolMessageType('DailyMacdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMACDRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyMacdResponse)
  })
_sym_db.RegisterMessage(DailyMacdResponse)

DailyMacdData = _reflection.GeneratedProtocolMessageType('DailyMacdData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYMACDDATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_macd_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyMacdData)
  })
_sym_db.RegisterMessage(DailyMacdData)

_DAILYMACDSERVICE = DESCRIPTOR.services_by_name['DailyMacdService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DAILYMACDREQUEST._serialized_start=241
  _DAILYMACDREQUEST._serialized_end=442
  _DAILYMACDRESPONSE._serialized_start=444
  _DAILYMACDRESPONSE._serialized_end=539
  _DAILYMACDDATA._serialized_start=541
  _DAILYMACDDATA._serialized_end=647
  _DAILYMACDSERVICE._serialized_start=650
  _DAILYMACDSERVICE._serialized_end=813
# @@protoc_insertion_point(module_scope)
