# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday_analytics/v1/intraday_bollinger.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIsystemathics/apis/services/intraday_analytics/v1/intraday_bollinger.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x95\x02\n\x18IntradayBollingerRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12<\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.Sampling\x12\x42\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x04 \x01(\x05\x12\x11\n\tdeviation\x18\x05 \x01(\x01\x12\x12\n\nadjustment\x18\x06 \x01(\x08\"r\n\x19IntradayBollingerResponse\x12U\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32G.systemathics.apis.services.intraday_analytics.v1.IntradayBollingerData\"\xde\x01\n\x15IntradayBollingerData\x12.\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05value\x18\x02 \x01(\x01\x12+\n\x05lower\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12+\n\x05upper\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12,\n\x06middle\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue2\xc9\x01\n\x18IntradayBollingerService\x12\xac\x01\n\x11IntradayBollinger\x12J.systemathics.apis.services.intraday_analytics.v1.IntradayBollingerRequest\x1aK.systemathics.apis.services.intraday_analytics.v1.IntradayBollingerResponseb\x06proto3')



_INTRADAYBOLLINGERREQUEST = DESCRIPTOR.message_types_by_name['IntradayBollingerRequest']
_INTRADAYBOLLINGERRESPONSE = DESCRIPTOR.message_types_by_name['IntradayBollingerResponse']
_INTRADAYBOLLINGERDATA = DESCRIPTOR.message_types_by_name['IntradayBollingerData']
IntradayBollingerRequest = _reflection.GeneratedProtocolMessageType('IntradayBollingerRequest', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBOLLINGERREQUEST,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayBollingerRequest)
  })
_sym_db.RegisterMessage(IntradayBollingerRequest)

IntradayBollingerResponse = _reflection.GeneratedProtocolMessageType('IntradayBollingerResponse', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBOLLINGERRESPONSE,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayBollingerResponse)
  })
_sym_db.RegisterMessage(IntradayBollingerResponse)

IntradayBollingerData = _reflection.GeneratedProtocolMessageType('IntradayBollingerData', (_message.Message,), {
  'DESCRIPTOR' : _INTRADAYBOLLINGERDATA,
  '__module__' : 'systemathics.apis.services.intraday_analytics.v1.intraday_bollinger_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.intraday_analytics.v1.IntradayBollingerData)
  })
_sym_db.RegisterMessage(IntradayBollingerData)

_INTRADAYBOLLINGERSERVICE = DESCRIPTOR.services_by_name['IntradayBollingerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _INTRADAYBOLLINGERREQUEST._serialized_start=345
  _INTRADAYBOLLINGERREQUEST._serialized_end=622
  _INTRADAYBOLLINGERRESPONSE._serialized_start=624
  _INTRADAYBOLLINGERRESPONSE._serialized_end=738
  _INTRADAYBOLLINGERDATA._serialized_start=741
  _INTRADAYBOLLINGERDATA._serialized_end=963
  _INTRADAYBOLLINGERSERVICE._serialized_start=966
  _INTRADAYBOLLINGERSERVICE._serialized_end=1167
# @@protoc_insertion_point(module_scope)
